package com.persagy.account.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.persagy.common.service.impl.SuperServiceImpl;
import com.persagy.common.utils.StringUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.persagy.account.mapper.SaasMenuMapper;
import com.persagy.account.mapper.SaasProductMapper;
import com.persagy.account.pojo.dto.SaasMenu;
import com.persagy.account.pojo.dto.SaasProduct;
import com.persagy.account.service.ISaasProductService;

/**
 * 产品信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-04-27 16:08:25
 */
@Service
public class SaasProductServiceImpl extends SuperServiceImpl<SaasProductMapper, SaasProduct> implements ISaasProductService {

	@Autowired
	private SaasMenuMapper saasMenuMapper;
	
	@Override
	@Transactional
	public boolean updateSaasProduct(SaasProduct saasProduct, boolean isUpdateMenu) {
		Integer result = this.baseMapper.updateById(saasProduct);
		if (SqlHelper.retBool(result) && isUpdateMenu) {
			// 更新菜单图标为此产品的图标
			LambdaUpdateWrapper<SaasMenu> updateWrapper = new SaasMenu.Builder().createUpdateWrapper().productId(saasProduct.getId()).builderUpdateWrapper();
			updateWrapper.set(SaasMenu::getMenuIcon, saasProduct.getProductIcon());
			this.saasMenuMapper.update(null, updateWrapper);
		}
		return SqlHelper.retBool(result);
	}
	
	@Override
	public boolean validProductCode(String productType, String productCode, String id) {
		LambdaQueryWrapper<SaasProduct> queryWrapper = new SaasProduct.BuilderQueryWrapper().productTypeEq(productType).productCodeEq(productCode).builder();
		SaasProduct selectOne = this.baseMapper.selectOne(queryWrapper);
		if (selectOne == null) {
			return true;
		}
		if (StringUtil.isNotBlank(id) && selectOne.getId().equals(id)) {
			return true;
		}
		return false;
	}

	@Override
	public boolean validProductName(String productType, String productName, String id) {
		LambdaQueryWrapper<SaasProduct> queryWrapper = new SaasProduct.BuilderQueryWrapper().productTypeEq(productType).productNameEq(productName).builder();
		SaasProduct selectOne = this.baseMapper.selectOne(queryWrapper);
		if (selectOne == null) {
			return true;
		}
		if (StringUtil.isNotBlank(id) && selectOne.getId().equals(id)) {
			return true;
		}
		return false;
	}

}
